check_recipe <- function(recipe, file) {
  # recipe: yaml recipe already read it
  # file: name of the file to clarify messages
  # output: errors or the total number of workflow (vars x regions) to compute
  message(paste("Checking recipe", file))
  if (!any(names(recipe) %in% "Analysis")) {
    stop("The recipe should has a element 'Analysis'.")
  }
  params <- c('Horizon', 'Time', 'Variables', 'Region', 'Grid', 'Workflow', 'Datasets')
  if (!all(params %in% names(recipe$Analysis))) {
    stop(paste("The element 'Analysis' in the recipe should contain these",
         "elements:", paste(params, collapse = " ")))
  }
  horizons <- c('Subseasonal', 'Seasonal', 'Decadal')
  if (!any(horizons %in% recipe$Analysis$Horizon)) {
    stop("The element 'Horizon' in the recipe should be one of the followings:",
         paste(horizons, collapse = " "))
  }
  # more checks
  # ...
  # calculate number of workflows to create for each variable and 
  if (length(recipe$Analysis$Horizon) > 1) {
     stop("Only 1 Horizon can be specified in the recipe")
  }
  nvar <- length(recipe$Analysis$Variables)
  if (length(recipe$Analysis$Region) > 3) {
    stop("The section 'Region' in the recipe should be checked.",
         "Global, Countries and Regional elements are expected.")
  }
  if (!is.logical(recipe$Analysis$Region$Global)) {
    stop("The element 'Global' in Region should be logical.")
  }
  nregions <- 0
  if (recipe$Analysis$Region$Global == TRUE) {
    nregions <- 1
  }
  if (recipe$Analysis$Region$Countries == TRUE) {
    nregions <- nregions + 1
  }
  if ("Regional" %in% names(recipe$Analysis$Region)) {
    nregions <- nregions + length(recipe$Analysis$Region$Regional)
    limits <- c('latmin', 'latmax', 'lonmin', 'lonmax')
    for (i in 1:length(recipe$Analysis$Region$Regional)) {
      if (!all(limits %in% names(recipe$Analysis$Region$Regional[[i]]))) {
        stop("Each region defined in element 'Regional' should have 4 elements:",
             paste(limits, collapse = " "))
      }
      # are numeric? class list mode list 
    }
  }
  # Check workflow: need to define restrictions 
  # only one calibration method
  message("Recipe checked succsessfully.")
}

